/*
 * FreakliesShop Voucher
 * Code-Beispiel zum Buch Patterns Kompakt, Verlag Springer Vieweg
 * Copyright 2014 Karl Eilebrecht
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.calamanari.pk.factorymethod;

import java.util.logging.Logger;

/**
 * FreakliesShop Voucher (Voucher from the little shop owned by Mrs. Freakly in Chicago) is a concrete product in this
 * FACTORY METHOD example scenario.
 * @author <a href="mailto:Karl.Eilebrecht(a/t)calamanari.de">Karl Eilebrecht</a>
 */
public class FreakliesShopVoucher extends AbstractVoucher {

    /**
     * logger
     */
    protected static final Logger LOGGER = Logger.getLogger(FreakliesShopVoucher.class.getName());

    /**
     * identifier for this voucher
     */
    private final int serialNumber;

    /**
     * Creates a new voucher.
     * @param serialNumber identifies the voucher
     * @param firstName first name of the voucher owner
     * @param lastName last name of the voucher owner
     * @param value voucher's value
     */
    public FreakliesShopVoucher(int serialNumber, String firstName, String lastName, double value) {
        super(firstName, lastName, value);
        this.serialNumber = serialNumber;
        LOGGER.fine("Concrete Product " + this.getClass().getSimpleName() + " created.");
    }

    @Override
    public String getId() {
        LOGGER.fine("getId() on concrete product " + this.getClass().getSimpleName() + " called.");
        return "S" + serialNumber;
    }

    @Override
    public String getVoucherDisplayCode() {
        LOGGER.fine("getVoucherDisplayCode() on concrete product " + this.getClass().getSimpleName() + " called.");
        return "v" + this.getFirstName().toLowerCase().charAt(0) + this.getLastName().toLowerCase().charAt(0)
                + serialNumber;
    }

    /**
     * Returns the serialNumber that was specified initially.
     * @return serial number of this FreakliesShop Voucher
     */
    public int getSerialNumber() {
        return this.serialNumber;
    }

}
